Implementation of the CellularInterface for u-blox C030 boards with N2xx modems. Note: requires the N211 module firmware to be at least 06.57 A01.02.

Dependents:   example-ublox-cellular-interface HelloMQTT example-ublox-cellular-interface_r410M example-ublox-mbed-client ... more

Revision:
4:2bf3875a13f1
Parent:
1:8ea78dce6b36
Child:
7:69e676f4af84
--- a/UbloxATCellularInterfaceN2xx.h	Fri Jul 07 13:15:59 2017 +0100
+++ b/UbloxATCellularInterfaceN2xx.h	Tue Aug 22 16:37:30 2017 +0100
@@ -64,8 +64,6 @@
 class UbloxATCellularInterfaceN2xx : public CellularBase, public NetworkStack, virtual public UbloxCellularBaseN2xx  {
 
 public:
-    // test command.
-    bool SendAT(const char *cmd);
 
     /** Constructor.
      *
@@ -142,10 +140,15 @@
      * 
      */     
     void set_LocalListenPort(int port);
+    
+    /** 
+     * Turns on the modem and reads the module information     
+     */
+    bool initialise();
 
     /** Connect to the cellular network and start the interface.
      *
      *  Attempts to connect to a cellular network.  Note: if init() has
      *  not been called beforehand, connect() will call it first.
      *
      *  @param sim_pin     PIN for the SIM card.
@@ -583,6 +586,7 @@
     
     nsapi_size_or_error_t receivefrom(int socketId, SocketAddress *address, int length, char *buf);
     nsapi_size_or_error_t sendto(SockCtrl *socket, const SocketAddress &address, const char *buf, int size);
+    bool sendATChopped(const char *);
     
     char hex_char(char c);
     int hex_to_bin(const char* s, char * buff, int length);
@@ -142,10 +140,15 @@
     /** Connect to the cellular network and start the interface.
      *
-     *  Attempts to connect to a cellular network.  Note: if init() has
+     *  Attempts to connect to a cellular network.  Note: if initialise() has
      *  not been called beforehand, connect() will call it first.
      *